var urlParams = new URLSearchParams(window.location.search);
const displayCoordinates = urlParams.has('displayCoordinates');

const cityDotStyle = function (city) {
    const cityName = city.name;
    const magnitude = people.filter(p => p.city === cityName).length;
    const radius = 3 + 2 * magnitude;
    return new ol.style.Style({
        image: new ol.style.Circle({
            radius: radius,
            fill: new ol.style.Fill({
                color: 'rgba(255, 0, 0, 0.4)',
            }),
            stroke: new ol.style.Stroke({
                color: 'rgba(255, 0, 0, 1)',
                width: 1,
            }),
        }),
    });
};

const getCityAt = function(map, pixel) {
    const feature = map.forEachFeatureAtPixel(pixel, function (feature) {
        return feature;
    });
    return feature?.city;
}


const displayCityInfo = function (map, pixel, info) {
    let city = getCityAt(map, pixel);
    if (city) {
        info.css({
            left: pixel[0] + 'px',
            top: pixel[1] + 15 + 'px',
        });
        var peopleInCity = people.filter(p => p.city === city.name);
        info.attr('data-original-title', city.name + ' (' + peopleInCity.length + ')')
            .attr('data-content', '<ul>' + peopleInCity.map(p => '<li>' + p.name + '</li>').join('') + '</ul>')
            .popover('show');
    } else {
        info.popover('hide');
    }
};

function formatClickCoordinate(coordinate) {
    return `
    <table>
      <tbody>
        <tr><th>lon/lat</th><td>${coordinate[0].toFixed(4)}, ${coordinate[1].toFixed(4)}</td></tr>
      </tbody>
    </table>`;
}

$(document).ready(function() {
    cities = cities.filter(city => people.some(person => person.city === city.name));

    var map = new ol.Map({
        target: 'map',
        layers: [
            new ol.layer.Tile({
                source: new ol.source.OSM()
            })
        ],
        view: new ol.View({
            center: ol.proj.fromLonLat([-0.5910, 44.8418], 'EPSG:3857'),
            zoom: 10
        })
    });
    var features = cities.map(city => {
        var feature = new ol.Feature(
            new ol.geom.Point(ol.proj.fromLonLat(city.lonLat))
        );
        feature.setStyle(cityDotStyle(city));
        feature.city = city;
        return feature;
    });
    var layer = new ol.layer.Vector({
        source: new ol.source.Vector({
            features: features,
        })
    });
    map.addLayer(layer);

    const info = $('#info');
    info.popover({
        animation: false,
        trigger: 'manual',
        placement: 'bottom',
        html: true,
    });

    map.on('pointermove', function (evt) {
        if (evt.dragging) {
            info.popover('hide');
            return;
        }
        displayCityInfo(map, map.getEventPixel(evt.originalEvent), info);
    });
    map.on('click', function (evt) {
        displayCityInfo(map, evt.pixel, info);
    });

    const coordinates = document.getElementById('coordinates');
    if (displayCoordinates) {
        map.on('singleclick', function (event) {
            coordinates.innerHTML = formatClickCoordinate(ol.proj.transform(event.coordinate, 'EPSG:3857', 'EPSG:4326'));
        });
    }
});